@@ -23,9 +23,9 @@ pub struct LittleEndian;
 value. The methods on `Endian` all return a cursor into a storage element.
 
 - `curr` computes the bit index of the count given. In Little-Endian order, this
-  is the identity function (bit indices count up "left" from LSb), and in
+  is the identity function (bit indices count up “left” from LSb), and in
   Big-Endian order, this subtracts the count given from `T::MASK` (bit indices
-  count down "right" from MSb).
+  count down “right” from MSb).
 - `next` computes the next index forward from the count given. In Little-Endian
   order, this increments (moving up from LSb towards MSb); in Big-Endian order,
   this decrements (moving down from MSb towards LSb).
@@ -35,11 +35,6 @@ value. The methods on `Endian` all return a cursor into a storage element.
 - `jump` computes a number of whole elements to move, as well as the bit index
   within the destination element of the target bit.
 
-Note that if the value returned from `next` is 0, or if the value returned from
-`prev` is `T::MASK`, then the client is responsible for moving to the
-neighboring element. No other signal will be raised for crossing over element
-boundaries.
-
 You should use `curr` to look up a bit at a known point, such as when indexing a
 `BitVec`; you should use `next` or `prev` to implement push, pop, and iteration;
 you should use `jump` only to implement striding iterators in a manner faster
@@ -92,7 +87,8 @@ pub trait Endian {
 	/// into an element. The second value indicates whether the decrement points
 	/// into a different element.
 	fn prev<T: Bits>(count: u8) -> (u8, bool) {
-		count.overflowing_sub(1)
+		let (next, wrap) = count.overflowing_sub(1);
+		(next & T::MASK, wrap)
 	}
 
 	/// Computes the bit index at a given semantic offset from the current
@@ -101,25 +97,25 @@ pub trait Endian {
 	/// Returns a tuple where the first value is the number of whole storage
 	/// elements to move, and the second is the bit index within the element.
 	fn jump<T: Bits>(count: u8, offset: isize) -> (isize, u8) {
-		assert!(count <= T::MASK, "Bit count out of range for the storage type");
+		assert!(count < T::WIDTH, "Bit count out of range for the storage type");
 		//  Add offset to *count*, not to the current bit index, because this
 		//  math doesn't know how to move around in an ordering. The offset is
 		//  signed in count order, not Endian order.
 		//  Subtraction can never fail, because count is always >= 0 and
-		//  0 - isize::MIN is isize::MIN, which does not overflow.
+		//  `0 - isize::MIN` is `isize::MIN`, which does not overflow.
 		//  In a non-overflowing addition, the result will be the position of
 		//  the target bit
 		match (count as isize).overflowing_add(offset) {
 			//  If the addition overflows, then the offset is positive. Add as
 			//  unsigned and use that.
-			//  Note that this is guaranteed not to overflow usize::MAX because
-			//  converting two positive signed integers to unsigned doubles the
-			//  domain, which will always be enormously wider than the domain of
-			//  count.
+			//  Note that this is guaranteed not to overflow `usize::MAX`
+			//  because converting two positive signed integers to unsigned
+			//  doubles the domain, which will always be enormously wider than
+			//  the domain of count.
 			(_, true) => {
 				let far = Self::curr::<T>(count) as usize + offset as usize;
 				//  The number of elements advanced is, conveniently, the number
-				//  of bits advanced integer divided by the number of bits in
+				//  of bits advanced integer-divided by the number of bits in
 				//  the elements, which even more conveniently, is equivalent to
 				//  right-shift by the number of bits required to index an
 				//  element. Note that we don't cast until *after* the shift, in
@@ -131,16 +127,15 @@ pub trait Endian {
 				let pos = (far & (T::MASK as usize)) as u8;
 				(elements, pos)
 			},
-			//  If far_bit is negative, then the jump leaves the element going
-			//  backward.
-			//  If far_bit is greater than T::MASK, then the jump leaves the
-			//  element going forward.
+			//  If `far` is negative, then the jump leaves the element going
+			//  backward. If `far` is greater than `T::MASK`, then the jump
+			//  leaves the element going forward.
 			(far, _) if far < 0 || far > T::MASK as isize => {
 				let elements = far >> T::BITS;
 				let pos = (far & (T::MASK as isize)) as u8;
 				(elements, Self::curr::<T>(pos))
 			},
-			//  Otherwise, far_bit is the *bit count* in the current element. It
+			//  Otherwise, `far` is the *bit count* in the current element. It
 			//  must still be converted from count to bit index.
 			(far, _) => {
 				(0, Self::curr::<T>(far as u8))
@@ -154,7 +149,7 @@ pub trait Endian {
 
 impl Endian for BigEndian {
 	fn curr<T: Bits>(count: u8) -> u8 {
-		assert!(count <= T::MASK, "Index out of range of the storage type");
+		assert!(count < T::WIDTH, "Index out of range of the storage type");
 		T::MASK - count
 	}
 
@@ -163,7 +158,7 @@ impl Endian for BigEndian {
 
 impl Endian for LittleEndian {
 	fn curr<T: Bits>(count: u8) -> u8 {
-		assert!(count <= T::MASK, "Index out of range of the storage type");
+		assert!(count < T::WIDTH, "Index out of range of the storage type");
 		count
 	}
 
@@ -174,47 +169,33 @@ impl Endian for LittleEndian {
 mod tests {
 	use super::*;
 
-	/*
-	All the comments below are because I didn't actually do the math correctly
-	when writing the test cases, and kept getting test failures on perfectly
-	sound code because I didn't grok what was actually going on. If you (either
-	someone who is not me, or my future self) decide to add more test cases to
-	this to harden expectations about what jump does, be absolutely sure you
-	have correct expectations before changing the code if your tests fail.
-
-	Be sure to remember that all the functions take a *semantic count*, not a
-	*bit index*, and as such you should **not** pass different values to
-	different Endian implementations in order to try to account for their
-	different counting styles.
-	*/
-
 	#[test]
 	fn incr_edge() {
-		// assert_eq!(LittleEndian::next::<u8>(7), (0, true));
-		// assert_eq!(BigEndian::next::<u8>(7), (7, true));
-		// assert_eq!(LittleEndian::next::<u16>(15), (0, true));
-		// assert_eq!(BigEndian::next::<u16>(15), (15, true));
-		// assert_eq!(LittleEndian::next::<u32>(31), (0, true));
-		// assert_eq!(BigEndian::next::<u32>(31), (31, true));
-		// assert_eq!(LittleEndian::next::<u64>(63), (0, true));
-		// assert_eq!(BigEndian::next::<u64>(63), (63, true));
+		assert_eq!(LittleEndian::next::<u8>(7), (0, true));
+		assert_eq!(BigEndian::next::<u8>(7), (0, true));
+		assert_eq!(LittleEndian::next::<u16>(15), (0, true));
+		assert_eq!(BigEndian::next::<u16>(15), (0, true));
+		assert_eq!(LittleEndian::next::<u32>(31), (0, true));
+		assert_eq!(BigEndian::next::<u32>(31), (0, true));
+		assert_eq!(LittleEndian::next::<u64>(63), (0, true));
+		assert_eq!(BigEndian::next::<u64>(63), (0, true));
 	}
 
 	#[test]
 	fn decr_edge() {
-		// assert_eq!(LittleEndian::prev::<u8>(0), (7, true));
-		// assert_eq!(BigEndian::prev::<u8>(0), (0, true));
-		// assert_eq!(LittleEndian::prev::<u16>(0), (15, true));
-		// assert_eq!(BigEndian::prev::<u16>(0), (0, true));
-		// assert_eq!(LittleEndian::prev::<u32>(0), (31, true));
-		// assert_eq!(BigEndian::prev::<u32>(0), (0, true));
-		// assert_eq!(LittleEndian::prev::<u64>(0), (63, true));
-		// assert_eq!(BigEndian::prev::<u64>(0), (0, true));
+		assert_eq!(LittleEndian::prev::<u8>(0), (7, true));
+		assert_eq!(BigEndian::prev::<u8>(0), (7, true));
+		assert_eq!(LittleEndian::prev::<u16>(0), (15, true));
+		assert_eq!(BigEndian::prev::<u16>(0), (15, true));
+		assert_eq!(LittleEndian::prev::<u32>(0), (31, true));
+		assert_eq!(BigEndian::prev::<u32>(0), (31, true));
+		assert_eq!(LittleEndian::prev::<u64>(0), (63, true));
+		assert_eq!(BigEndian::prev::<u64>(0), (63, true));
 	}
 
 	#[test]
 	fn jump_inside_elt() {
-		//  TODO: test the other two types.
+		//  TODO(myrrlyn): test the other two types.
 
 		let (elt, bit) = LittleEndian::jump::<u8>(5, 2);
 		assert_eq!(elt, 0);
@@ -238,7 +219,7 @@ mod tests {
 
 	#[test]
 	fn jump_backwards() {
-		//  TODO: Test the other three types.
+		//  TODO(myrrlyn): Test the other three types.
 
 		let (elt, bit) = LittleEndian::jump::<u32>(10, -15);
 		assert_eq!(elt, -1);
@@ -256,7 +237,7 @@ mod tests {
 
 	#[test]
 	fn jump_forwards() {
-		//  TODO: Test the other three types.
+		//  TODO(myrrlyn): Test the other three types.
 
 		let (elt, bit) = LittleEndian::jump::<u32>(25, 10);
 		assert_eq!(elt, 1);
@@ -272,12 +253,13 @@ mod tests {
 
 	#[test]
 	fn jump_overflow() {
-		//  TODO: Test the other three types.
+		//  TODO(myrrlyn): Test the other three types.
 
 		//  Force an overflowing stride. We expect the destination bit *count*
 		//  to be one less than the starting point (which on BigEndian will be
-		//  MASK - start - 1), and the elements skipped to be isize::MIN >> BITS
-		//  (an overflowing isize add will set the high bit as the usize repr).
+		//  `MASK - start - 1`), and the elements skipped to be
+		//  `isize::MIN >> BITS` (an overflowing isize add will set the high bit
+		//  as the `usize` repr).
 		let start = 20;
 		let (elt, bit) = LittleEndian::jump::<u32>(start, ::std::isize::MAX);
 
@@ -303,5 +285,17 @@ mod tests {
 		for n in 0 .. 64 {
 			assert_eq!(n, BigEndian::curr::<u64>(BigEndian::curr::<u64>(n)));
 		}
+		for n in 0 .. 8 {
+			assert_eq!(n, LittleEndian::curr::<u8>(LittleEndian::curr::<u8>(n)));
+		}
+		for n in 0 .. 16 {
+			assert_eq!(n, LittleEndian::curr::<u16>(LittleEndian::curr::<u16>(n)));
+		}
+		for n in 0 .. 32 {
+			assert_eq!(n, LittleEndian::curr::<u32>(LittleEndian::curr::<u32>(n)));
+		}
+		for n in 0 .. 64 {
+			assert_eq!(n, LittleEndian::curr::<u64>(LittleEndian::curr::<u64>(n)));
+		}
 	}
 }
